function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

var useHeadingsExtractor = function useHeadingsExtractor() {
  var _useState = React.useState([]),
      nestedHeadings = _useState[0],
      setNestedHeadings = _useState[1];

  React.useEffect(function () {
    var headingElements = Array.from(document.querySelectorAll('h2, h3'));
    var newNestedHeadings = getNestedHeadings(headingElements);
    setNestedHeadings(newNestedHeadings);
  }, []);
  return nestedHeadings;
};

var getNestedHeadings = function getNestedHeadings(headingElements) {
  var nestedHeadings = [];
  headingElements.forEach(function (heading) {
    var title = heading.innerText,
        id = heading.id;

    if (heading.nodeName === 'H2') {
      nestedHeadings.push({
        id: id,
        title: title,
        items: []
      });
    } else if (heading.nodeName === 'H3' && nestedHeadings.length > 0) {
      nestedHeadings[nestedHeadings.length - 1].items.push({
        id: id,
        title: title,
        items: []
      });
    }
  });
  return nestedHeadings;
};

var styles = {"link":"_71S8l","active":"_3sodH","ul":"_16OkV","li":"_2lBIR"};

var useActiveHeadingObserver = function useActiveHeadingObserver() {
  var _React$useState = React__default.useState(),
      activeId = _React$useState[0],
      setActiveId = _React$useState[1];

  var headingElementsRef = React.useRef({});
  React.useEffect(function () {
    var callback = function callback(headings) {
      headingElementsRef.current = headings.reduce(function (map, headingElement) {
        map[headingElement.target.id] = headingElement;
        return map;
      }, headingElementsRef.current);
      var visibleHeadings = [];
      Object.keys(headingElementsRef.current).forEach(function (key) {
        var headingElement = headingElementsRef.current[key];
        if (headingElement.isIntersecting) visibleHeadings.push(headingElement);
      });

      var getIndexFromId = function getIndexFromId(id) {
        return headingElements.findIndex(function (heading) {
          return heading.id === id;
        });
      };

      if (visibleHeadings.length === 1) {
        setActiveId(visibleHeadings[0].target.id);
      } else if (visibleHeadings.length > 1) {
        var sortedVisibleHeadings = visibleHeadings.sort(function (a, b) {
          return getIndexFromId(a.target.id) > getIndexFromId(b.target.id);
        });
        setActiveId(sortedVisibleHeadings[0].target.id);
      }
    };

    var observer = new IntersectionObserver(callback, {
      rootMargin: '0px 0px -40% 0px'
    });
    var headingElements = Array.from(document.querySelectorAll('h2, h3'));
    headingElements.forEach(function (element) {
      return observer.observe(element);
    });
    return function () {
      return observer.disconnect();
    };
  }, [setActiveId]);
  return activeId;
};

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var classnames = createCommonjsModule(function (module) {
/*!
  Copyright (c) 2018 Jed Watson.
  Licensed under the MIT License (MIT), see
  http://jedwatson.github.io/classnames
*/
/* global define */

(function () {

	var hasOwn = {}.hasOwnProperty;

	function classNames() {
		var classes = [];

		for (var i = 0; i < arguments.length; i++) {
			var arg = arguments[i];
			if (!arg) continue;

			var argType = typeof arg;

			if (argType === 'string' || argType === 'number') {
				classes.push(arg);
			} else if (Array.isArray(arg)) {
				if (arg.length) {
					var inner = classNames.apply(null, arg);
					if (inner) {
						classes.push(inner);
					}
				}
			} else if (argType === 'object') {
				if (arg.toString === Object.prototype.toString) {
					for (var key in arg) {
						if (hasOwn.call(arg, key) && arg[key]) {
							classes.push(key);
						}
					}
				} else {
					classes.push(arg.toString());
				}
			}
		}

		return classes.join(' ');
	}

	if ( module.exports) {
		classNames.default = classNames;
		module.exports = classNames;
	} else {
		window.classNames = classNames;
	}
}());
});

var TableOfContents = function TableOfContents(_ref) {
  var className = _ref.className,
      activeClassName = _ref.activeClassName;
  var activeHeadingId = useActiveHeadingObserver();
  var headings = useHeadingsExtractor();
  return React__default.createElement(Headings, {
    headings: headings,
    activeHeadingId: activeHeadingId,
    className: className,
    activeClassName: activeClassName
  });
};

var Headings = function Headings(_ref2) {
  var headings = _ref2.headings,
      activeHeadingId = _ref2.activeHeadingId,
      className = _ref2.className,
      activeClassName = _ref2.activeClassName;
  return React__default.createElement("ul", {
    className: classnames(styles.ul, className)
  }, headings.map(function (heading) {
    return React__default.createElement("li", {
      key: heading.id,
      className: classnames(styles.li)
    }, React__default.createElement("a", {
      href: "#" + heading.id,
      className: classnames(styles.link, activeHeadingId === heading.id && styles.active, activeHeadingId === heading.id && activeClassName),
      onClick: function onClick(e) {
        var _document$querySelect;

        e.preventDefault();
        (_document$querySelect = document.querySelector("#" + heading.id)) === null || _document$querySelect === void 0 ? void 0 : _document$querySelect.scrollIntoView({
          behavior: 'smooth'
        });
      }
    }, heading.title), heading.items.length > 0 && React__default.createElement(Headings, {
      headings: heading.items,
      activeHeadingId: activeHeadingId,
      activeClassName: activeClassName
    }));
  }));
};

exports.Headings = Headings;
exports.default = TableOfContents;
//# sourceMappingURL=index.js.map
